==> 0.8.14-beta.tar.gz: lib/dart_periphery.dart <==
// Copyright (c) 2021, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

export 'src/version.dart' show getCperipheryVersion, DART_PERIPHERY_VERSION;
export 'src/library.dart'
    show useSharedLibray, setCustomLibrary, useLocalLibrary;
export 'src/led.dart' show Led, LedException, getLedErrorCode;
export 'src/pwm.dart'
    show PWM, PWMexception, getPWMerrorCode, Polarity, PWMerrorCode;
export 'src/gpio.dart'
    show
        GPIOpolling,
        GPIOerrorCode,
        GPIOdirection,
        GPIOedge,
        GPIObias,
        GPIO,
        GPIOdrive,
        GPIOreadEvent,
        PollMultipleEvent,
        GPIOconfig,
        GPIOexception,
        getGPIOerrorCode;
export 'src/serial.dart'
    show
        SerialReadEvent,
        SerialException,
        Baudrate,
        DataBits,
        StopBits,
        SerialErrorCode,
        Parity,
        getSerialErrorCode,
        baudrate2Int,
        databits2Int,
        stopbits2Int,
        Serial;
export 'src/i2c.dart'
    show
        I2CmsgFlags,
        I2CmsgFlags2Int,
        NativeI2Cmsg,
        NativeI2CmsgHelper,
        I2Cmsg,
        I2CerrorCode,
        getI2CerrorCode,
        I2Cexception,
        I2C;
export 'src/spi.dart' show SPI, SPImode, SPIexception, getSPIerrorCode;
export 'src/mmio.dart'
    show MMIO, MMIOexception, MMIOerrorCode, getMMIOerrorCode;
export 'src/hardware/util.dart' show BitOrder;
export 'src/hardware/bme280.dart'
    show
        BME280result,
        BME280,
        BME280model,
        BME280exception,
        BMP280_ID,
        BME280_ID,
        BME280_DEFAULT_I2C_ADDRESS,
        BME280_ALTERNATIVE_I2C_ADDRESS;
export 'src/hardware/sht31.dart'
    show
        SHT31,
        SHT31result,
        SHT31excpetion,
        SHT31_ALTERNATIVE_I2C_ADDRESS,
        SHT31_DEFAULT_I2C_ADDRESS;
export 'src/hardware/extension_hat.dart'
    show
        DigitalValue,
        PINMODE,
        NanoHatHub,
        LedBarColor,
        LedBarLed,
        BakeBitLedBar,
        GrovePiPlusHat,
        GroveBaseHat;
export 'src/hardware/gesture_sensor.dart'
    show GestureSensor, GestureSensorException, Gesture;
export 'src/hardware/sgp30.dart'
    show
        SGP30,
        SGP30Measurement,
        RawMeasurement,
        FeatureSetVersion,
        SGP30excpetion;
export 'src/hardware/mpu6050.dart' show MPU6050, MPU6050exception;

==> 0.8.17-beta.tar.gz: lib/dart_periphery.dart <==
// Copyright (c) 2021, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

export 'src/version.dart' show getCperipheryVersion, DART_PERIPHERY_VERSION;
export 'src/library.dart'
    show useSharedLibray, setCustomLibrary, useLocalLibrary;
export 'src/led.dart' show Led, LedException, getLedErrorCode;
export 'src/pwm.dart'
    show PWM, PWMexception, getPWMerrorCode, Polarity, PWMerrorCode;
export 'src/gpio.dart'
    show
        GPIOpolling,
        GPIOerrorCode,
        GPIOdirection,
        GPIOedge,
        GPIObias,
        GPIO,
        GPIOdrive,
        GPIOreadEvent,
        PollMultipleEvent,
        GPIOconfig,
        GPIOexception,
        getGPIOerrorCode;
export 'src/serial.dart'
    show
        SerialReadEvent,
        SerialException,
        Baudrate,
        DataBits,
        StopBits,
        SerialErrorCode,
        Parity,
        getSerialErrorCode,
        baudrate2Int,
        databits2Int,
        stopbits2Int,
        Serial;
export 'src/i2c.dart'
    show
        I2CmsgFlags,
        I2CmsgFlags2Int,
        NativeI2Cmsg,
        NativeI2CmsgHelper,
        I2Cmsg,
        I2CerrorCode,
        getI2CerrorCode,
        I2Cexception,
        I2C;
export 'src/spi.dart' show SPI, SPImode, SPIexception, getSPIerrorCode;
export 'src/mmio.dart'
    show MMIO, MMIOexception, MMIOerrorCode, getMMIOerrorCode;
export 'src/hardware/util.dart' show BitOrder;
export 'src/hardware/bosch.dart' show OversamplingMultiplier;
export 'src/hardware/bme280.dart'
    show
        BME280result,
        BME280,
        BME280model,
        BME280exception,
        BMP280_ID,
        BME280_ID,
        BME280_DEFAULT_I2C_ADDRESS,
        BME280_ALTERNATIVE_I2C_ADDRESS,
        FilterCoefficient,
        OperatingMode,
        StandbyDuration;
export 'src/hardware/sht31.dart'
    show
        SHT31,
        SHT31result,
        SHT31excpetion,
        SHT31_ALTERNATIVE_I2C_ADDRESS,
        SHT31_DEFAULT_I2C_ADDRESS;
export 'src/hardware/extension_hat.dart'
    show
        DigitalValue,
        PINMODE,
        NanoHatHub,
        LedBarColor,
        LedBarLed,
        BakeBitLedBar,
        GrovePiPlusHat,
        GroveBaseHat;
export 'src/hardware/gesture_sensor.dart'
    show GestureSensor, GestureSensorException, Gesture;
export 'src/hardware/sgp30.dart'
    show
        SGP30,
        SGP30Measurement,
        RawMeasurement,
        FeatureSetVersion,
        SGP30excpetion;
export 'src/hardware/mpu6050.dart' show MPU6050, MPU6050exception;
export 'src/hardware/bme680.dart'
    show
        BME680,
        BME680exception,
        BME680result,
        BME680_DEFAULT_I2C_ADDRESS,
        BME680_ALTERNATIVE_I2C_ADDRESS,
        PowerMode,
        FilterSize,
        HeaterProfile,
        SENSOR_READ_RETRY_COUNTER;
